import sys
import os
import h5py
import numpy as np
from glob import glob
from NuRadioMC.utilities import merge_hdf5
#from NuRadioMC.utilities import Veff
import Veff_ccnc as Veff

""" script that calculates Veff json files while merging on the fly, adds a set of combined (OR) triggers for deep/shallow  """

import argparse

parser = argparse.ArgumentParser(description='Generate effective volumes **per non-merged directory** with additional stats on simulated/triggered events (doing merging on the fly)')

parser.add_argument('--step3_dir', type=str,
                    default="/lustre/fs22/group/radio/shallman/Veffs_sensitivity_rnog/simulation_output",
                    help='step3 directory where merged files are stored')

parser.add_argument('--step4_dir', type=str, default="test",
                    help='step4 directory (output directory) to store per-directory Veff files')

parser.add_argument('--subdir', type=str, default="16_4.64e+17_6.81e+17",
                    help='"e", "mu", or "tau"')

parser.add_argument('--detector', type=str, default="baseline_array",
                    help='detector config name')

args = parser.parse_args()

input_dir = args.step3_dir+"/"+args.subdir
step4dir = args.step4_dir

if not os.path.exists(step4dir):
    os.makedirs(step4dir)



input_dir = args.step3_dir+"/"+args.subdir
output_jsonfile_cc = args.step4_dir + "/ccnc/" + "__".join(["Veff_cc", args.subdir, ".json"])
output_jsonfile_nc = args.step4_dir + "/ccnc/" + "__".join(["Veff_nc", args.subdir, ".json"])
output_jsonfile = args.step4_dir + "/coarse_zenithbinning/" + "__".join(["Veff", args.subdir, ".json"])
output_jsonfile_fine = args.step4_dir + "/fine_zenithbinning/" + "__".join(["Veff", args.subdir, ".json"])
output_jsonfile_exc = args.step4_dir + "/coarse_zenithbinning_exclusiveTriggers/" +  "__".join(["Veff", args.subdir, ".json"])

for subdir in ["ccnc", "coarse_zenithbinning", "fine_zenithbinning", "coarse_zenithbinning_exclusiveTriggers"]:
    if not os.path.exists("/".join([args.step4_dir, subdir])):
        os.makedirs("/".join([args.step4_dir, subdir]))

print("producing CC")
if not os.path.exists(output_jsonfile_cc):
    v_cc = Veff.get_Veff_Aeff(input_dir, oversampling_theta=1, interaction_type="cc")
    Veff.export(output_jsonfile_cc, v_cc, export_format="json")
print("producing NC")
if not os.path.exists(output_jsonfile_nc):
    v_nc = Veff.get_Veff_Aeff(input_dir, oversampling_theta=1, interaction_type="nc")
    Veff.export(output_jsonfile_nc, v_nc, export_format="json")
print("producing combined")
if not os.path.exists(output_jsonfile):
    v = Veff.get_Veff_Aeff(input_dir, oversampling_theta=1)
    Veff.export(output_jsonfile, v, export_format="json")
print("producing combined fine")
if not os.path.exists(output_jsonfile_fine):
    v_fine = Veff.get_Veff_Aeff(input_dir, oversampling_theta=4)
    Veff.export(output_jsonfile_fine, v_fine, export_format="json")

print("producing combined with exclusive triggers")
if not os.path.exists(output_jsonfile_exc):
    v = Veff.get_Veff_Aeff(input_dir, oversampling_theta=1)
    Veff.export(output_jsonfile_exc, v, export_format="json")
